sync

package
v0.0.0-...-76a6b52 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 27, 2025 License: Apache-2.0 Imports: 21 Imported by: 0

Documentation

Overview

Package sync implements a system to fetch GitHub repositories concurrently.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Sync

func Sync(ctx context.Context, repositories []string, opts Options) error

Sync performs the synchronisation of repositories to the database provided in the options.

Types

type Options

type Options struct {
	DB           *ent.Client
	Token        string
	CreatedAfter time.Time

	DebugHTTP bool
}

Options repsent the options to run Sync. These match the flags provided on the command line.

Directories

Path Synopsis
internal
synchub
Package synchub provides a data structure to manage:
Package synchub provides a data structure to manage:

Jump to